@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.948'; # TRIAL
+$Email::MIME::VERSION = '1.950'; # TRIAL
 use Email::Simple 2.212; # nth header value
 use parent qw(Email::Simple);
 
@@ -410,7 +410,7 @@ sub parts_multipart {
   # body.  This is a horrible hack, although it's debatable whether it was
   # better or worse when it was $self->{body} = shift @bits ... -- rjbs,
   # 2006-11-27
-  $self->SUPER::body_set(shift @bits) if ($bits[0] || '') !~ /.*:.*/;
+  $self->SUPER::body_set(shift @bits) if index(($bits[0] || ''), ':') == -1;
 
   my $bits = @bits;
 
@@ -449,7 +449,7 @@ sub filename {
   my ($self, $force) = @_;
   return $gcache{$self} if exists $gcache{$self};
 
-  my $dis = $self->header("Content-Disposition") || '';
+  my $dis = $self->header_raw("Content-Disposition") || '';
   my $attrs = parse_content_disposition($dis)->{attributes};
   my $name = $attrs->{filename}
     || $self->{ct}{attributes}{name};
@@ -940,7 +940,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.948
+version 1.950
 
 =head1 SYNOPSIS
 
@@ -1379,7 +1379,7 @@ Simon Cozens <simon@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Vandiver Anirvan Chatterjee Arthur Axel 'fREW' Schmidt Brian Cassidy Damian Lukowski Dan Book David Steinbrunner Dotan Dimet dxdc Eric Wong Geraint Edwards Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall (alh) memememomo Michael McClimon Pali Ricardo Signes Shawn Sorichetti Tomohiro Hosaka
+=for stopwords Alex Vandiver Anirvan Chatterjee Arthur Axel 'fREW' Schmidt Brian Cassidy Damian Lukowski Dan Book David Steinbrunner Dotan Dimet dxdc Eric Wong Geraint Edwards ivulfson Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall (alh) memememomo Michael McClimon Mishrakk Pali Ricardo Signes Shawn Sorichetti Tomohiro Hosaka
 
 =over 4
 
@@ -1429,6 +1429,10 @@ Geraint Edwards <gedge-oss@yadn.org>
 
 =item *
 
+ivulfson <9122139+ivulfson@users.noreply.github.com>
+
+=item *
+
 Jesse Luehrs <doy@tozt.net>
 
 =item *
@@ -1453,6 +1457,10 @@ Michael McClimon <michael@mcclimon.org>
 
 =item *
 
+Mishrakk <48946018+Mishrakk@users.noreply.github.com>
+
+=item *
+
 Pali <pali@cpan.org>
 
 =item *
